Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterChainConstructor ¶
func RegisterChainConstructor(chainID uint32, c ChainConstructor)
RegisterChainConstructor is called by chain backends to register their ChainConstructors.
Types ¶
type BadQueryError ¶
type BadQueryError error
type Chain ¶
type Chain interface {
Connect(context.Context) (*sync.WaitGroup, error)
// Query may be needed if clients are the auditors, since some clients might
// not have e.g. txindex enabled for utxo-based assets.
// Query(context.Context, Query) (Result, error)
Connected() bool
CheckBond(*tanka.Bond) error
}
Chain is an interface that must be implemented by every blockchain backend.
type ChainConfig ¶
type ChainConfig struct {
ConfigPath string
}
type ChainConstructor ¶
ChainConstructor is a constructor for a Chain.
Click to show internal directories.
Click to hide internal directories.